#[repr(u8)]pub enum PathAttribute {
Show 13 variants
Origin(OriginPathAttribute),
AsPath(AsPathAttribute),
NextHop(NextHopPathAttribute),
MultiExitDisc(MultiExitDiscPathAttribute),
LocalPref(LocalPrefPathAttribute),
AtomicAggregate(AtomicAggregatePathAttribute),
Aggregator(AggregatorPathAttribute),
Communitites(CommunitiesPathAttribute),
MpReachNlri(MpReachNlriPathAttribute),
MpUnreachNlri(MpUnreachNlriPathAttribute),
ExtendedCommunities(ExtendedCommunitiesPathAttribute),
LargeCommunities(LargeCommunitiesPathAttribute),
UnknownPathAttribute {
flags: PathAttributeFlags,
type_code: u8,
payload: Vec<u8>,
},
}Variants
Origin(OriginPathAttribute)
AsPath(AsPathAttribute)
NextHop(NextHopPathAttribute)
MultiExitDisc(MultiExitDiscPathAttribute)
LocalPref(LocalPrefPathAttribute)
AtomicAggregate(AtomicAggregatePathAttribute)
Aggregator(AggregatorPathAttribute)
Communitites(CommunitiesPathAttribute)
MpReachNlri(MpReachNlriPathAttribute)
MpUnreachNlri(MpUnreachNlriPathAttribute)
ExtendedCommunities(ExtendedCommunitiesPathAttribute)
LargeCommunities(LargeCommunitiesPathAttribute)
UnknownPathAttribute
Implementations
Sourceimpl PathAttribute
impl PathAttribute
Sourcepub fn from_wire<'a>(
ctx: &ParserContext,
buf: &'a [u8],
) -> IResult<&'a [u8], Self, BgpParserError<&'a [u8]>>
pub fn from_wire<'a>( ctx: &ParserContext, buf: &'a [u8], ) -> IResult<&'a [u8], Self, BgpParserError<&'a [u8]>>
The from_wire parser for PathAttribute consumes type and length which it uses to
determine how many bytes to take and pass down to the corresponding sub-parser.
pub fn to_wire(&self, ctx: &ParserContext, out: &mut BytesMut) -> Result<()>