pub struct ExtendedNextHop {
pub afi: AddressFamilyId,
pub safi: SubsequentAfi,
pub nh_afi: AddressFamilyId,
}Expand description
ExtendedNextHop allows for the nexthop to be for a different address family
than the one being used to advertise prefixes for. E.g. it allows for sending
IPv4 prefixes with an IPv6 nexthop.
Fields
afi: AddressFamilyIdThe Address Family to update the nexthop format for.
safi: SubsequentAfiThe Subsequent Address Family to update the nexthop format for.
nh_afi: AddressFamilyIdThe Address Family that nexthops will be encoded as.