pub struct ParserContext {
pub four_octet_asn: Option<bool>,
pub address_family: Option<AddressFamilyId>,
}Fields
four_octet_asn: Option<bool>Whether thi parser is being run with a peer that is RFC6793 compliant.
address_family: Option<AddressFamilyId>Which address family should be parsed by default with this parser.