pub enum ExtendedCommunity {
AsSpecific {
typ: u8,
sub_typ: u8,
global_admin: u16,
local_admin: u32,
},
Ipv4AddrSpecific {
typ: u8,
sub_typ: u8,
global_admin: u32,
local_admin: u16,
},
Opaque {
typ: u8,
sub_typ: u8,
value: [u8; 5],
},
RouteTarget {
typ: u8,
sub_typ: u8,
global_admin: u32,
local_admin: u16,
},
RouteOrigin {
typ: u8,
sub_typ: u8,
global_admin: u16,
local_admin: u32,
},
}Variants
AsSpecific
AS Specific Extended Community as specified in Section 3.1 of RFC4360.
Ipv4AddrSpecific
Ipv4 Address Specific Extended Community as specified in Section 3.2 of RFC4360.
Opaque
Opaque Extended Community as specified in Section 3.3 of RFC4360.
RouteTarget
Route Target Community as specified in Section 4 of RFC4360.
RouteOrigin
Route Origin Community as specified in Section 5 of RFC4360.
Implementations
Sourceimpl ExtendedCommunity
impl ExtendedCommunity
pub fn from_wire<'a>( _: &ParserContext, buf: &'a [u8], ) -> IResult<&'a [u8], Self, BgpParserError<&'a [u8]>>
pub fn to_wire(&self, _: &ParserContext, out: &mut BytesMut) -> Result<()>
pub fn wire_len(&self, _: &ParserContext) -> Result<u16>